@@ -2,7 +2,7 @@ import os
 import localstack_client.config
 
 # LocalStack version
-VERSION = '0.11.0.5'
+VERSION = '0.11.1.1'
 
 # constant to represent the "local" region, i.e., local machine
 REGION_LOCAL = 'local'
@@ -31,7 +31,8 @@ DEFAULT_PORT_KMS_BACKEND = 4554
 DEFAULT_PORT_EVENTS_BACKEND = 4553
 DEFAULT_PORT_LOGS_BACKEND = 4552
 DEFAULT_PORT_SSM_BACKEND = 4551
-
+DEFAULT_PORT_STS_BACKEND = 4550
+DEFAULT_PORT_SECRETSMANAGER_BACKEND = 4549
 DEFAULT_PORT_WEB_UI = 8080
 
 LOCALHOST = 'localhost'
@@ -64,6 +65,7 @@ PATH_USER_REQUEST = '_user_request_'
 
 # name of LocalStack Docker image
 DOCKER_IMAGE_NAME = 'localstack/localstack'
+DOCKER_IMAGE_NAME_LIGHT = 'localstack/localstack-light'
 
 # backdoor API path used to retrieve or update config variables
 CONFIG_UPDATE_PATH = '/?_config_'
@@ -86,13 +88,18 @@ FALSE_STRINGS = ('0', 'false', 'False')
 LAMBDA_TEST_ROLE = 'arn:aws:iam::%s:role/lambda-test-role' % TEST_AWS_ACCOUNT_ID
 
 # installation constants
-ELASTICSEARCH_JAR_URL = 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-7.1.0-linux-x86_64.tar.gz'
+ELASTICSEARCH_URLS = {
+    '7.4.0': 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-7.4.0-linux-x86_64.tar.gz',
+    '7.1.0': 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-7.1.0-linux-x86_64.tar.gz',
+    '6.7.0': 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-6.7.0.zip'
+}
+ELASTICSEARCH_DEFAULT_VERSION = '7.1.0'
 # See https://docs.aws.amazon.com/ja_jp/elasticsearch-service/latest/developerguide/aes-supported-plugins.html
 ELASTICSEARCH_PLUGIN_LIST = ['analysis-icu', 'ingest-attachment', 'analysis-kuromoji',
  'mapper-murmur3', 'mapper-size', 'analysis-phonetic', 'analysis-smartcn', 'analysis-stempel', 'analysis-ukrainian']
 # Default ES modules to exclude (save apprx 66MB in the final image)
 ELASTICSEARCH_DELETE_MODULES = ['ingest-geoip']
-ELASTICMQ_JAR_URL = 'https://s3-eu-west-1.amazonaws.com/softwaremill-public/elasticmq-server-0.15.5.jar'
+ELASTICMQ_JAR_URL = 'https://s3-eu-west-1.amazonaws.com/softwaremill-public/elasticmq-server-0.15.7.jar'
 STS_JAR_URL = 'https://repo1.maven.org/maven2/com/amazonaws/aws-java-sdk-sts/1.11.14/aws-java-sdk-sts-1.11.14.jar'
 STEPFUNCTIONS_ZIP_URL = 'https://s3.amazonaws.com/stepfunctionslocal/StepFunctionsLocal.zip'
 KMS_URL_PATTERN = 'https://s3-eu-west-2.amazonaws.com/local-kms/localstack/v3/local-kms.<arch>.bin'
