@@ -26,7 +26,7 @@ from moto.cloudformation.exceptions import ValidationError, UnformattedGetAttTem
 from localstack import config
 from localstack.constants import DEFAULT_PORT_CLOUDFORMATION_BACKEND, TEST_AWS_ACCOUNT_ID, MOTO_ACCOUNT_ID
 from localstack.utils.aws import aws_stack, aws_responses
-from localstack.utils.common import FuncThread, short_uid, recurse_object, clone, json_safe
+from localstack.utils.common import FuncThread, short_uid, recurse_object, clone, json_safe, md5, canonical_json
 from localstack.stepfunctions import models as sfn_models
 from localstack.services.infra import (
     get_service_protocol, start_proxy_for_service, do_run, canonicalize_api_names
@@ -58,14 +58,20 @@ MODEL_MAP = {
     'AWS::StepFunctions::StateMachine': sfn_models.StateMachine,
     'AWS::CloudFormation::Stack': service_models.CloudFormationStack,
     'AWS::SSM::Parameter': service_models.SSMParameter,
-    'AWS::Logs::LogGroup': service_models.LogsLogGroup
+    'AWS::Logs::LogGroup': service_models.LogsLogGroup,
+    'AWS::KinesisFirehose::DeliveryStream': service_models.FirehoseDeliveryStream,
+    'AWS::SecretsManager::Secret': service_models.SecretsManagerSecret,
+    'AWS::Elasticsearch::Domain': service_models.ElasticsearchDomain,
+    'AWS::Events::Rule': service_models.EventsRule,
+    'AWS::S3::BucketPolicy': service_models.S3BucketPolicy
 }
 
 
 def start_cloudformation(port=None, asynchronous=False, update_listener=None):
     port = port or config.PORT_CLOUDFORMATION
     backend_port = DEFAULT_PORT_CLOUDFORMATION_BACKEND
-    print('Starting mock CloudFormation (%s port %s)...' % (get_service_protocol(), port))
+    print('Starting mock CloudFormation service in %s ports %s (recommended) and %s (deprecated)...' % (
+        get_service_protocol(), config.EDGE_PORT, port))
     start_proxy_for_service('cloudformation', port, backend_port, update_listener)
     if RUN_SERVER_IN_PROCESS:
         cmd = 'python "%s" cloudformation -p %s -H 0.0.0.0' % (__file__, backend_port)
@@ -151,6 +157,18 @@ def update_physical_resource_id(resource):
         elif isinstance(resource, service_models.LogsLogGroup):
             resource.physical_resource_id = resource.params.get('LogGroupName')
 
+        elif isinstance(resource, service_models.FirehoseDeliveryStream):
+            resource.physical_resource_id = resource.params.get('DeliveryStreamName')
+
+        elif isinstance(resource, service_models.SecretsManagerSecret):
+            resource.physical_resource_id = resource.params.get('Name')
+
+        elif isinstance(resource, service_models.EventsRule):
+            resource.physical_resource_id = resource.params.get('Name')
+
+        elif isinstance(resource, service_models.ElasticsearchDomain):
+            resource.physical_resource_id = resource.params.get('DomainName')
+
         else:
             LOG.warning('Unable to determine physical_resource_id for resource %s' % type(resource))
 
@@ -200,6 +218,7 @@ def apply_patches():
             update=False, force_create=False):
         stack_name = resources_map.get('AWS::StackName')
         resource_hash_key = (stack_name, logical_id)
+        props = resource_json['Properties'] = resource_json.get('Properties') or {}
 
         # If the current stack is being updated, avoid infinite recursion
         updating = CURRENTLY_UPDATING_RESOURCES.get(resource_hash_key)
@@ -213,10 +232,22 @@ def apply_patches():
             return None
         _, resource_json, _ = resource_tuple
 
-        # add some missing default props which otherwise cause deployments to fail
-        props = resource_json['Properties'] = resource_json.get('Properties') or {}
-        if resource_json['Type'] == 'AWS::Lambda::EventSourceMapping' and not props.get('StartingPosition'):
-            props['StartingPosition'] = 'LATEST'
+        def add_default_props(resource_props):
+            """ apply some fixes which otherwise cause deployments to fail """
+            res_type = resource_props['Type']
+            props = resource_props.get('Properties', {})
+            if res_type == 'AWS::Lambda::EventSourceMapping' and not props.get('StartingPosition'):
+                props['StartingPosition'] = 'LATEST'
+            # generate default names for certain resource types
+            default_attrs = (('AWS::IAM::Role', 'RoleName'), ('AWS::Events::Rule', 'Name'))
+            for entry in default_attrs:
+                if res_type == entry[0] and not props.get(entry[1]):
+                    props[entry[1]] = 'cf-%s-%s' % (stack_name, md5(canonical_json(props)))
+
+        # add some fixes and default props which otherwise cause deployments to fail
+        add_default_props(resource_json)
+        for resource in resources_map._resource_json_map.values():
+            add_default_props(resource)
 
         # check if this resource already exists in the resource map
         resource = resources_map._parsed_resources.get(logical_id)
@@ -312,7 +343,8 @@ def apply_patches():
             LOG.debug('Updating resource id: %s - %s, %s - %s' % (existing_id, new_res_id, resource, resource_json))
             if new_res_id:
                 LOG.info('Updating resource ID from %s to %s (%s)' % (existing_id, new_res_id, region_name))
-                update_resource_id(resource, new_res_id, props, region_name)
+                update_resource_id(resource, new_res_id, props,
+                    region_name, stack_name, resources_map._resource_json_map)
             else:
                 LOG.warning('Unable to extract id for resource %s: %s' % (logical_id, result))
 
@@ -328,7 +360,7 @@ def apply_patches():
         if isinstance(resource, sfn_models.StateMachine) and not props.get('StateMachineName'):
             props['StateMachineName'] = resource.name
 
-    def update_resource_id(resource, new_id, props, region_name):
+    def update_resource_id(resource, new_id, props, region_name, stack_name, resource_map):
         """ Update and fix the ID(s) of the given resource. """
 
         # NOTE: this is a bit of a hack, which is required because
@@ -363,11 +395,13 @@ def apply_patches():
             resource.id = new_id
         elif isinstance(resource, apigw_models.Resource):
             api_id = props['RestApiId']
+            api_id = template_deployer.resolve_refs_recursively(stack_name, api_id, resource_map)
             backend.apis[api_id].resources.pop(resource.id, None)
             backend.apis[api_id].resources[new_id] = resource
             resource.id = new_id
         elif isinstance(resource, apigw_models.Deployment):
             api_id = props['RestApiId']
+            api_id = template_deployer.resolve_refs_recursively(stack_name, api_id, resource_map)
             backend.apis[api_id].deployments.pop(resource['id'], None)
             backend.apis[api_id].deployments[new_id] = resource
             resource['id'] = new_id
@@ -536,6 +570,14 @@ def apply_patches():
     IAM_Role_get_cfn_attribute_orig = iam_models.Role.get_cfn_attribute
     iam_models.Role.get_cfn_attribute = IAM_Role_get_cfn_attribute
 
+    # Patch IAM Role model
+    # https://github.com/localstack/localstack/issues/925
+    @property
+    def IAM_Role_physical_resource_id(self):
+        return self.name
+
+    iam_models.Role.physical_resource_id = IAM_Role_physical_resource_id
+
     # Patch SNS Topic get_cfn_attribute(..) method in moto
     def SNS_Topic_get_cfn_attribute(self, attribute_name):
         result = SNS_Topic_get_cfn_attribute_orig(self, attribute_name)
@@ -546,6 +588,28 @@ def apply_patches():
     SNS_Topic_get_cfn_attribute_orig = sns_models.Topic.get_cfn_attribute
     sns_models.Topic.get_cfn_attribute = SNS_Topic_get_cfn_attribute
 
+    # Patch ES get_cfn_attribute(..) method
+    def ES_get_cfn_attribute(self, attribute_name):
+        if attribute_name in ['Arn', 'DomainArn']:
+            return aws_stack.es_domain_arn(self.params.get('DomainName'))
+        if attribute_name == 'DomainEndpoint':
+            if not hasattr(self, '_domain_endpoint'):
+                es_details = aws_stack.connect_to_service('es').describe_elasticsearch_domain(
+                    DomainName=self.params.get('DomainName'))
+                self._domain_endpoint = es_details['DomainStatus']['Endpoint']
+            return self._domain_endpoint
+        raise UnformattedGetAttTemplateException()
+
+    service_models.ElasticsearchDomain.get_cfn_attribute = ES_get_cfn_attribute
+
+    # Patch Firehose get_cfn_attribute(..) method
+    def Firehose_get_cfn_attribute(self, attribute_name):
+        if attribute_name == 'Arn':
+            return aws_stack.firehose_stream_arn(self.params.get('DeliveryStreamName'))
+        raise UnformattedGetAttTemplateException()
+
+    service_models.FirehoseDeliveryStream.get_cfn_attribute = Firehose_get_cfn_attribute
+
     # Patch LambdaFunction create_from_cloudformation_json(..) method in moto
     @classmethod
     def Lambda_create_from_cloudformation_json(cls, resource_name, cloudformation_json, region_name):
@@ -577,6 +641,18 @@ def apply_patches():
     if not hasattr(lambda_models.LambdaFunction, 'update_from_cloudformation_json'):
         lambda_models.LambdaFunction.update_from_cloudformation_json = Lambda_update_from_cloudformation_json
 
+    # Patch Role update_from_cloudformation_json(..) method
+    @classmethod
+    def Role_update_from_cloudformation_json(cls,
+            original_resource, new_resource_name, cloudformation_json, region_name):
+        props = cloudformation_json.get('Properties', {})
+        original_resource.name = props.get('RoleName') or original_resource.name
+        original_resource.assume_role_policy_document = props.get('AssumeRolePolicyDocument')
+        return original_resource
+
+    if not hasattr(iam_models.Role, 'update_from_cloudformation_json'):
+        iam_models.Role.update_from_cloudformation_json = Role_update_from_cloudformation_json
+
     # patch ApiGateway Deployment
     def depl_delete_from_cloudformation_json(resource_name, resource_json, region_name):
         properties = resource_json['Properties']
@@ -729,12 +805,13 @@ def apply_patches():
                     break
             set_status('%s_FAILED' % action)
             raise Exception('Unable to resolve all CloudFormation resources after traversing ' +
-                'dependency tree (maximum depth %s reached): %s' % (MAX_DEPENDENCY_DEPTH, unresolved.keys()))
+                'dependency tree (maximum depth %s reached): %s' % (MAX_DEPENDENCY_DEPTH, list(unresolved.keys())))
 
         # NOTE: We're running the loop in the background, as it might take some time to complete
         FuncThread(run_loop).start()
 
     def initialize_resources(self):
+        self.resource_map.load()
         self.resource_map.create()
         self.output_map.create()
         run_dependencies_deployment_loop(self, 'CREATE')
